## ecctl deployment kibana create

Creates a Kibana instance

### Synopsis

Creates a Kibana deployment, limitting the creation scope to Kibana resources.
There's a few ways to create an Kibana deployment, sane default values are provided, making
the command work out of the box even when no parameters are set. When version is not specified,
the matching elasticsearch deployment version will be used. These are the available options:

  * Simplified flags: --zones <zone count> --size <node memory in MB>
  * File definition: --file=<file path> (shorthand: -f). The definition can be found in:
    https://www.elastic.co/guide/en/cloud-enterprise/current/definitions.html#KibanaPayload

As an option "--generate-payload" can be used in order to obtain the generated KibanaPayload
that would be sent as a request, save it, update or extend the topology and create an Kibana
deployment using the saved payload with the "--file" flag.

```
ecctl deployment kibana create --id <deployment-id> [flags]
```

### Examples

```
## Create a single node cluster. The command will exit after the API response has been returned, 
## without waiting until the deployment resources have been created. To make the command wait until
the resources have been created use the "--track" flag.
$ ecctl deployment kibana create --id=fc2fe19a8c4f43d385004febe4e63900 --track
{
  "id": "fc2fe19a8c4f43d385004febe4e63900",
  "name": "fc2fe19a8c4f43d385004febe4e63900",
  "resources": [
    {
      "elasticsearch_cluster_ref_id": "elasticsearch",
      "id": "8d37cff942fb482ba7a3cac10eea943a",
      "kind": "kibana",
      "ref_id": "kibana",
      "region": "ece-region"
    },
    {
      "cloud_id": "fc2fe19a8c4f43d385004febe4e63900:MTkyLjE2OC40NC4xMC5pcC5lcy5pbzo5MjQzJDJjOGRkMWQxYmExNDQyZGU4NDU2NmY0ZTkxY2M1YWJmJDhkMzdjZmY5NDJmYjQ4MmJhN2EzY2FjMTBlZWE5NDNh",
      "id": "2c8dd1d1ba1442de84566f4e91cc5abf",
      "kind": "elasticsearch",
      "ref_id": "elasticsearch",
      "region": "ece-region"
    }
  ]
}
Cluster [8d37cff942fb482ba7a3cac10eea943a][Kibana]: running step "wait-until-running" (Plan duration 1.480086699s)...
Cluster [2c8dd1d1ba1442de84566f4e91cc5abf][Elasticsearch]: finished running all the plan steps (Total plan duration: 1.598400189s)
Cluster [8d37cff942fb482ba7a3cac10eea943a][Kibana]: running step "set-maintenance" (Plan duration 1m2.277750264s)...
Cluster [8d37cff942fb482ba7a3cac10eea943a][Kibana]: finished running all the plan steps (Total plan duration: 1m7.544473245s)

## Save the definition to a file for later use.
$ ecctl deployment kibana create --generate-payload --id fc2fe19a8c4f43d385004febe4e63900 --zones 2 --size 2048 > kibana_create_example.json

## Create the deployment piping through the file contents tracking the creation progress
$ cat kibana_create_example.json | dev-cli deployment kibana create --track --id fc2fe19a8c4f43d385004febe4e63900
[...]
```

### Options

```
      --deployment-template string    Optional deployment template ID, automatically obtained from the current deployment
      --elasticsearch-ref-id string   Optional Elasticsearch ref ID where the Kibana deployment will connect to
  -f, --file string                   KibanaPayload file definition. See help for more information
      --generate-payload              Returns the KibanaPayload without actually creating the deployment resources
  -h, --help                          help for create
      --id string                     Deployment ID where to create the Kibana deployment
      --name string                   Optional name to set for the Kibana deployment (Overrides name if present)
      --ref-id string                 RefId for the Kibana deployment (default "kibana")
      --size int32                    Memory (RAM) in MB that each of the deployment nodes will have (default 1024)
  -t, --track                         Tracks the progress of the performed task
      --version string                Version to use, if not specified, the deployment's stack version will be used
      --zones int32                   Number of zones the deployment will span (default 1)
```

### Options inherited from parent commands

```
      --apikey string      API key to use to authenticate (If empty will look for EC_APIKEY environment variable)
      --config string      Config name, used to have multiple configs in $HOME/.ecctl/<env> (default "config")
      --force              Do not ask for confirmation
      --format string      Formats the output using a Go template
      --host string        Base URL to use
      --insecure           Skips all TLS validation
      --message string     A message to set on cluster operation
      --output string      Output format [text|json] (default "text")
      --pass string        Password to use to authenticate (If empty will look for EC_PASS environment variable)
      --pprof              Enables pprofing and saves the profile to pprof-20060102150405
  -q, --quiet              Suppresses the configuration file used for the run, if any
      --timeout duration   Timeout to use on all HTTP calls (default 30s)
      --trace              Enables tracing saves the trace to trace-20060102150405
      --user string        Username to use to authenticate (If empty will look for EC_USER environment variable)
      --verbose            Enable verbose mode
```

### SEE ALSO

* [ecctl deployment kibana](ecctl_deployment_kibana.md)	 - Manages Kibana instances

